summaryrefslogtreecommitdiffstats
path: root/tests/DumpRenderTree
diff options
context:
space:
mode:
authorGuang Zhu <guangzhu@google.com>2011-01-12 22:57:41 -0800
committerGuang Zhu <guangzhu@google.com>2011-01-12 22:57:41 -0800
commit71716223201a01a4f4b6fe182ad97720b7d06124 (patch)
treedd64b1bfe4fb614edb55a0723148496645a7cf42 /tests/DumpRenderTree
parent63be8dd178447fce289c940638cd37aa560d9de3 (diff)
downloadframeworks_base-71716223201a01a4f4b6fe182ad97720b7d06124.zip
frameworks_base-71716223201a01a4f4b6fe182ad97720b7d06124.tar.gz
frameworks_base-71716223201a01a4f4b6fe182ad97720b7d06124.tar.bz2
change webkit test data path
path changed from "/sdcard/android/" to "/sdcard/webkit/". the old path clashes with "/sdcard/Android/" and has some odd issues under FUSE Change-Id: I57102dca99612bdd7b4d1f196e43436cd1276281
Diffstat (limited to 'tests/DumpRenderTree')
-rwxr-xr-xtests/DumpRenderTree/assets/run_layout_tests.py12
-rwxr-xr-xtests/DumpRenderTree/assets/run_page_cycler.py4
-rw-r--r--tests/DumpRenderTree/src/com/android/dumprendertree/FileList.java4
-rw-r--r--tests/DumpRenderTree/src/com/android/dumprendertree/FsUtils.java10
-rw-r--r--tests/DumpRenderTree/src/com/android/dumprendertree/LayoutTestsAutoTest.java10
5 files changed, 20 insertions, 20 deletions
diff --git a/tests/DumpRenderTree/assets/run_page_cycler.py b/tests/DumpRenderTree/assets/run_page_cycler.py
index 8b8fb38..692f32e 100755
--- a/tests/DumpRenderTree/assets/run_page_cycler.py
+++ b/tests/DumpRenderTree/assets/run_page_cycler.py
@@ -6,7 +6,7 @@
Usage:
Run a single page cycler test:
- run_page_cycler.py "file:///sdcard/android/page_cycler/moz/start.html?auto=1\&iterations=10"
+ run_page_cycler.py "file:///sdcard/webkit/page_cycler/moz/start.html\?auto=1\&iterations=10"
"""
import logging
@@ -32,7 +32,7 @@ def main(options, args):
# Include all tests if none are specified.
if not args:
- print "need a URL, e.g. file:///sdcard/android/page_cycler/moz/start.html"
+ print "need a URL, e.g. file:///sdcard/webkit/page_cycler/moz/start.html\?auto=1\&iterations=10"
sys.exit(1)
else:
path = ' '.join(args);
diff --git a/tests/DumpRenderTree/src/com/android/dumprendertree/FileList.java b/tests/DumpRenderTree/src/com/android/dumprendertree/FileList.java
index 73d7363..4a47a0e 100644
--- a/tests/DumpRenderTree/src/com/android/dumprendertree/FileList.java
+++ b/tests/DumpRenderTree/src/com/android/dumprendertree/FileList.java
@@ -181,7 +181,7 @@ public abstract class FileList extends ListActivity
}
protected void setupPath() {
- mPath = Environment.getExternalStorageDirectory() + "/android/layout_tests";
+ mPath = Environment.getExternalStorageDirectory() + "/webkit/layout_tests";
mBaseLength = mPath.length();
}
@@ -189,7 +189,7 @@ public abstract class FileList extends ListActivity
protected int mBaseLength;
protected String mFocusFile;
protected int mFocusIndex;
-
+
private final static int OPEN_DIRECTORY = 0;
private final static int RUN_TESTS = 1;
diff --git a/tests/DumpRenderTree/src/com/android/dumprendertree/FsUtils.java b/tests/DumpRenderTree/src/com/android/dumprendertree/FsUtils.java
index 5d34e25..b7d2c26 100644
--- a/tests/DumpRenderTree/src/com/android/dumprendertree/FsUtils.java
+++ b/tests/DumpRenderTree/src/com/android/dumprendertree/FsUtils.java
@@ -35,15 +35,15 @@ public class FsUtils {
private static final String LOGTAG = "FsUtils";
static final String EXTERNAL_DIR = Environment.getExternalStorageDirectory().toString();
static final String HTTP_TESTS_PREFIX =
- EXTERNAL_DIR + "/android/layout_tests/http/tests/";
+ EXTERNAL_DIR + "/webkit/layout_tests/http/tests/";
static final String HTTPS_TESTS_PREFIX =
- EXTERNAL_DIR + "/android/layout_tests/http/tests/ssl/";
+ EXTERNAL_DIR + "/webkit/layout_tests/http/tests/ssl/";
static final String HTTP_LOCAL_TESTS_PREFIX =
- EXTERNAL_DIR + "/android/layout_tests/http/tests/local/";
+ EXTERNAL_DIR + "/webkit/layout_tests/http/tests/local/";
static final String HTTP_MEDIA_TESTS_PREFIX =
- EXTERNAL_DIR + "/android/layout_tests/http/tests/media/";
+ EXTERNAL_DIR + "/webkit/layout_tests/http/tests/media/";
static final String HTTP_WML_TESTS_PREFIX =
- EXTERNAL_DIR + "/android/layout_tests/http/tests/wml/";
+ EXTERNAL_DIR + "/webkit/layout_tests/http/tests/wml/";
private FsUtils() {
//no creation of instances
diff --git a/tests/DumpRenderTree/src/com/android/dumprendertree/LayoutTestsAutoTest.java b/tests/DumpRenderTree/src/com/android/dumprendertree/LayoutTestsAutoTest.java
index 8aa3c69..050b779 100644
--- a/tests/DumpRenderTree/src/com/android/dumprendertree/LayoutTestsAutoTest.java
+++ b/tests/DumpRenderTree/src/com/android/dumprendertree/LayoutTestsAutoTest.java
@@ -129,11 +129,11 @@ public class LayoutTestsAutoTest extends ActivityInstrumentationTestCase2<TestSh
static final int DEFAULT_TIMEOUT_IN_MILLIS = 5000;
static final String EXTERNAL_DIR = Environment.getExternalStorageDirectory().toString();
- static final String LAYOUT_TESTS_ROOT = EXTERNAL_DIR + "/android/layout_tests/";
- static final String LAYOUT_TESTS_RESULT_DIR = EXTERNAL_DIR + "/android/layout_tests_results/";
- static final String ANDROID_EXPECTED_RESULT_DIR = EXTERNAL_DIR + "/android/expected_results/";
- static final String LAYOUT_TESTS_LIST_FILE = EXTERNAL_DIR + "/android/layout_tests_list.txt";
- static final String TEST_STATUS_FILE = EXTERNAL_DIR + "/android/running_test.txt";
+ static final String LAYOUT_TESTS_ROOT = EXTERNAL_DIR + "/webkit/layout_tests/";
+ static final String LAYOUT_TESTS_RESULT_DIR = EXTERNAL_DIR + "/webkit/layout_tests_results/";
+ static final String ANDROID_EXPECTED_RESULT_DIR = EXTERNAL_DIR + "/webkit/expected_results/";
+ static final String LAYOUT_TESTS_LIST_FILE = EXTERNAL_DIR + "/webkit/layout_tests_list.txt";
+ static final String TEST_STATUS_FILE = EXTERNAL_DIR + "/webkit/running_test.txt";
static final String LAYOUT_TESTS_RESULTS_REFERENCE_FILES[] = {
"results/layout_tests_passed.txt",
"results/layout_tests_failed.txt",
diff --git a/tests/DumpRenderTree/assets/run_layout_tests.py b/tests/DumpRenderTree/assets/run_layout_tests.py
index ceac5d2..21c02ec 100755
--- a/tests/DumpRenderTree/assets/run_layout_tests.py
+++ b/tests/DumpRenderTree/assets/run_layout_tests.py
@@ -4,8 +4,8 @@
First, you need to get an SD card or sdcard image that has layout tests on it.
Layout tests are in following directory:
- /sdcard/android/layout_tests
- For example, /sdcard/android/layout_tests/fast
+ /sdcard/webkit/layout_tests
+ For example, /sdcard/webkit/layout_tests/fast
Usage:
Run all tests under fast/ directory:
@@ -22,7 +22,7 @@
use --refresh-test-list option *once* to re-generate test list on the card.
Some other options are:
- --rebaseline generates expected layout tests results under /sdcard/android/expected_result/
+ --rebaseline generates expected layout tests results under /sdcard/webkit/expected_result/
--time-out-ms (default is 8000 millis) for each test
--adb-options="-e" passes option string to adb
--results-directory=..., (default is ./layout-test-results) directory name under which results are stored.
@@ -57,8 +57,8 @@ def DumpRenderTreeFinished(adb_cmd):
output: adb_cmd string
"""
- # pull /sdcard/android/running_test.txt, if the content is "#DONE", it's done
- shell_cmd_str = adb_cmd + " shell cat /sdcard/android/running_test.txt"
+ # pull /sdcard/webkit/running_test.txt, if the content is "#DONE", it's done
+ shell_cmd_str = adb_cmd + " shell cat /sdcard/webkit/running_test.txt"
adb_output = subprocess.Popen(shell_cmd_str, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()[0]
return adb_output.strip() == "#DONE"
@@ -207,7 +207,7 @@ def main(options, args):
# Get the running_test.txt
logging.error("DumpRenderTree crashed, output:\n" + adb_output)
- shell_cmd_str = adb_cmd + " shell cat /sdcard/android/running_test.txt"
+ shell_cmd_str = adb_cmd + " shell cat /sdcard/webkit/running_test.txt"
crashed_test = ""
while not crashed_test:
(crashed_test, err) = subprocess.Popen(